@@ -1,7 +1,7 @@
 package Perinci::Access::Lite;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2015-12-17'; # DATE
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -101,7 +101,13 @@ sub request {
 
             require Perinci::Sub::Normalize;
             $meta = Perinci::Sub::Normalize::normalize_function_metadata($meta);
-            return [200, "OK ($action)", $meta] if $action eq 'meta';
+            if ($action eq 'meta') {
+                $meta->{_orig_args_as} = $meta->{args_as};
+                $meta->{args_as} = 'hash';
+                $meta->{_orig_result_naked} = $meta->{result_naked};
+                $meta->{result_naked} = 0;
+                return [200, "OK ($action)", $meta];
+            }
 
             # form args (and add special args)
             my $args = { %{$extra->{args} // {}} }; # shallow copy
@@ -210,7 +216,7 @@ Perinci::Access::Lite - A lightweight Riap client library
 
 =head1 VERSION
 
-This document describes version 0.11 of Perinci::Access::Lite (from Perl distribution Perinci-Access-Lite), released on 2015-09-03.
+This document describes version 0.12 of Perinci::Access::Lite (from Perl distribution Perinci-Access-Lite), released on 2015-12-17.
 
 =head1 DESCRIPTION
 
